@@ -1,7 +1,9 @@
 # MIT licensed
-# Copyright (c) 2013-2020 lilydjwg <lilydjwg@gmail.com>, et al.
+# Copyright (c) 2013-2021 lilydjwg <lilydjwg@gmail.com>, et al.
 
-from pkg_resources import parse_version
+from packaging.version import Version
+
+from nvchecker.api import RichResult
 
 async def get_version(name, conf, *, cache, **kwargs):
   package = conf.get('pypi') or name
@@ -14,8 +16,11 @@ async def get_version(name, conf, *, cache, **kwargs):
   if use_pre_release:
     version = sorted(
       data['releases'].keys(),
-      key = parse_version,
+      key = Version,
     )[-1]
   else:
     version = data['info']['version']
-  return version
+  return RichResult(
+    version = version,
+    url = f'https://pypi.org/project/{package}/{version}/',
+  )
